package example.filesystem.callback;

import example.filesystem.backend.FileSystem;
import org.apache.ws.resource.example.filesystem.MountPointDirectoryDocument;
import org.apache.ws.resource.properties.ResourceProperty;
import org.apache.ws.resource.properties.SetResourcePropertyCallback;
import org.apache.ws.resource.properties.impl.CallbackFailedException;
import org.apache.xmlbeans.XmlString;

import javax.xml.namespace.QName;

/**
 * A callback for the MountPointDirectory resource property.
 */
public class MountPointCallback implements SetResourcePropertyCallback
{
    FileSystem m_fileSystem;

    public MountPointCallback(FileSystem fileSystem)
    {
        m_fileSystem = fileSystem;
    }

    public void deleteProperty( QName propQName) throws CallbackFailedException
    {
        return; // no need to implement - WSRF will never call delete for a prop whose minOccurs != 0
    }

    public void insertProperty(Object[] propElems) throws CallbackFailedException
    {
        return; // no need to implement - WSRF will never call insert for a prop whose minOccurs == its maxOccurs
    }

    public void updateProperty(Object[] propElems) throws CallbackFailedException
    {
        // MountPointDirectory prop has cardinality of 1..1, so WSRF will ensure that the passed array will always have exactly one element
        XmlString xString = (XmlString) propElems[0];
        m_fileSystem.setMountPoint( xString.getStringValue() );
    }

    public ResourceProperty refreshProperty(ResourceProperty prop)  throws CallbackFailedException
    {
        XmlString xString = (XmlString) prop.get( 0 );
        xString.setStringValue( m_fileSystem.getMountPoint() );
        return prop;
    }
}
