package org.apache.ws.resource.example.filesystem;

import org.apache.ws.resource.impl.AbstractResourceHome;

import java.util.Map;

/**
 * This class should <em>not</em> be modified.
 * <p/>
 * The class acts as an extension of the AbstractResourceHome which
 * maintains a reference to the STATIC map needed for accessing resources via JNDI.
 * <p/>
 * This ensures the resources will be accessible if serialized via JNDI in certain platforms.
 */
abstract class AbstractFilesystemHome extends AbstractResourceHome
{

    /**
     * Map containing all FilesystemResource instances - this map <em>must</em> be static for
     * compatibility with certain JNDI providers.
     */
    private static Map s_resources;

    /**
     * Returns a map of all FilesystemResource instances. Used by the {@link AbstractResourceHome}
     * superclass.
     */
    protected synchronized final Map getResourceMap()
    {
        if ( s_resources == null )
        {
            s_resources = AbstractResourceHome.createResourceMap( m_resourceIsPersistent );
        }
        return s_resources;
    }

}
